==> jc-1.4.0.tar.gz: soot/jimple/toolkits/scalar/ConstantPropagatorAndFolder.h <==
// public class soot.jimple.toolkits.scalar.ConstantPropagatorAndFolder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 2b75113c97e0a022 soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder_H_
#define _JC_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$sub_refs	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$refs	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$nonrefs	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$object	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vmethods	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vtable	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vtype	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$method_info$internalTransform$9abd4924859b68a3;

// Static methods
extern struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$object *_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$method$v$717605377ba86c29(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vmethods	soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$refs {
    _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$sub_refs	soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$sub_nonrefs	soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$object {
	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vtype _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/scalar/ConstantPropagatorAndFolder.h <==
// public class soot.jimple.toolkits.scalar.ConstantPropagatorAndFolder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 2b75113c97e0a022 soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder_H_
#define _JC_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$sub_refs	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$refs	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$nonrefs	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$object	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vmethods	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vtable	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vtype	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$method_info$internalTransform$9abd4924859b68a3;

// Static methods
extern struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$object *_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$method$v$717605377ba86c29(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vmethods	soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$refs {
    _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$sub_refs	soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$sub_nonrefs	soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$object {
	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$vtype _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_ConstantPropagatorAndFolder_H_ */
